Package: cogena
Version: 1.44.0
Title: co-expressed gene-set enrichment analysis
Authors@R: c(person("Zhilong", "Jia", role =c("aut", "cre"), 
    email="zhilongjia@gmail.com"), 
    person("Michael", "Barnes", role = "aut", email="m.r.barnes@qmul.ac.uk"))
Description: cogena is a workflow for co-expressed gene-set enrichment analysis.
    It aims to discovery smaller scale, but highly correlated cellular events that
    may be of great biological relevance. A novel pipeline for drug discovery and
    drug repositioning based on the cogena workflow is proposed. Particularly,
    candidate drugs can be predicted based on the gene expression of disease-related
    data, or other similar drugs can be identified based on the gene expression
    of drug-related data. Moreover, the drug mode of action can be disclosed by
    the associated pathway analysis. In summary, cogena is a flexible workflow for
    various gene set enrichment analysis for co-expressed genes, with a focus on
    pathway/GO analysis and drug repositioning.
biocViews: Clustering, GeneSetEnrichment, GeneExpression,
        Visualization, Pathways, KEGG, GO, Microarray, Sequencing,
        SystemsBiology, DataRepresentation, DataImport
Depends: R (>= 3.6), cluster, ggplot2, kohonen
Imports: methods, class, gplots, mclust, amap, apcluster, foreach,
        parallel, doParallel, fastcluster, corrplot, biwt, Biobase,
        reshape2, stringr, tibble, tidyr, dplyr, devtools
Suggests: knitr, rmarkdown (>= 2.1)
Collate: dist_class.R genecl_class.R cogena_class.R Class_methods.R
        cogena.R upDownGene.R PEI.R sota.R pClusters.R coExp.R
        clEnrich.R clEnrich_one.R enrichment.R gene2set.R
        geneInCluster.R geneExpInCluster.R corInCluster.R gmt2list.R
        gmtlist2file.R heatmap.3.R heatmapCluster.R heatmapPEI.R
        heatmapCmap.R
License: LGPL-3
LazyData: true
Encoding: UTF-8
URL: https://github.com/zhilongjia/cogena
NeedsCompilation: no
BugReports: https://github.com/zhilongjia/cogena/issues
VignetteBuilder: knitr
RoxygenNote: 7.0.2
git_url: https://git.bioconductor.org/packages/cogena
git_branch: RELEASE_3_22
git_last_commit: 5672c90
git_last_commit_date: 2025-10-29
Repository: Bioconductor 3.22
Date/Publication: 2025-10-29
Packaged: 2025-10-30 03:16:22 UTC; biocbuild
Author: Zhilong Jia [aut, cre],
  Michael Barnes [aut]
Maintainer: Zhilong Jia <zhilongjia@gmail.com>
