# Generated by roxygen2: do not edit by hand

S3method(plot,sota)
S3method(print,sota)
export(PEI)
export(clEnrich)
export(clEnrich_one)
export(coExp)
export(corInCluster)
export(enrichment)
export(gene2set)
export(geneExpInCluster)
export(geneInCluster)
export(gmt2list)
export(gmtlist2file)
export(heatmapCluster)
export(heatmapCmap)
export(heatmapPEI)
export(logfc)
export(sota)
export(upDownGene)
exportClasses(cogena)
exportClasses(genecl)
exportMethods(clusterMethods)
exportMethods(geneclusters)
exportMethods(mat)
exportMethods(nClusters)
exportMethods(show)
exportMethods(summary)
import(amap)
import(apcluster)
import(biwt)
import(class)
import(cluster)
import(devtools)
import(doParallel)
import(dplyr)
import(fastcluster)
import(foreach)
import(ggplot2)
import(gplots)
import(methods)
import(parallel)
import(reshape2)
importFrom(corrplot,corrplot)
importFrom(kohonen,som)
importFrom(kohonen,somgrid)
importFrom(mclust,Mclust)
importFrom(mclust,mclustBIC)
importMethodsFrom(Biobase,exprs)
